@@ -19,41 +19,33 @@
 #![warn(unused_extern_crates)]
 #![forbid(unsafe_code)]
 // Documentation
-#![cfg_attr(nightly, feature(doc_cfg, external_doc))]
-#![cfg_attr(nightly, doc(include = "../documentation/concepts/network_server.md"))]
+// todo: readd in Rust 1.54
+// #![doc = include_str!("../documentation/concepts/network_server.md")]
 
 #[macro_use]
 extern crate derivative;
 #[macro_use]
 extern crate tracing;
 
-pub mod config;
 pub use config::*;
-
-pub mod errors;
+pub use drop_join::*;
 pub use errors::*;
-
-pub mod inbound;
 pub use inbound::*;
-
-pub mod message;
 pub use message::*;
-
-pub mod node;
 pub use node::*;
-
-pub mod outbound;
-pub use outbound::*;
-
-pub mod peers;
 pub use peers::*;
-
-pub mod stats;
-pub use stats::*;
-
-pub mod sync;
+pub use snarkos_metrics::stats::*;
 pub use sync::*;
 
+pub mod config;
+mod drop_join;
+pub mod errors;
+pub mod inbound;
+pub mod message;
+pub mod node;
+pub mod peers;
+pub mod sync;
+
 /// The maximum number of block hashes that can be requested or provided in a single batch.
 pub const MAX_BLOCK_SYNC_COUNT: u32 = 64;
 /// The maximum amount of time allowed to process a single batch of sync blocks. It should be aligned
