@@ -14,16 +14,20 @@
 // You should have received a copy of the GNU General Public License
 // along with the snarkOS library. If not, see <https://www.gnu.org/licenses/>.
 
-use crate::{stats, Node, State};
-use snarkos_consensus::Miner;
-use snarkvm_dpc::{testnet1::instantiated::*, AccountAddress, Storage};
-
-use tracing::*;
-
 use std::{sync::Arc, thread, time::Duration};
 
+use futures::executor::block_on;
+use snarkvm_dpc::{testnet1::instantiated::*, AccountAddress, Storage};
+use tokio::task;
+use tracing::*;
+
+use snarkos_consensus::Miner;
+use snarkos_metrics::{self as metrics, misc::*};
+
+use crate::{Node, State};
+
 /// Parameters for spawning a miner that runs proof of work to find a block.
-pub struct MinerInstance<S: Storage> {
+pub struct MinerInstance<S: Storage + core::marker::Sync + Send + 'static> {
     miner_address: AccountAddress<Components>,
     node: Node<S>,
 }
@@ -37,7 +41,7 @@ impl<S: Storage + Send + Sync + 'static> MinerInstance<S> {
     /// Spawns a new miner on a new thread using MinerInstance parameters.
     /// Once a block is found, A block message is sent to all peers.
     /// Calling this function multiple times will spawn additional listeners on separate threads.
-    pub fn spawn(self) -> thread::JoinHandle<()> {
+    pub fn spawn(self) -> task::JoinHandle<()> {
         let local_address = self.node.local_address().unwrap();
         info!("Initializing Aleo miner - Your miner address is {}", self.miner_address);
         let miner = Miner::new(
@@ -49,7 +53,7 @@ impl<S: Storage + Send + Sync + 'static> MinerInstance<S> {
         let mut mining_failure_count = 0;
         let mining_failure_threshold = 10;
 
-        let mining_thread = thread::Builder::new().name("snarkOS_miner".into()).spawn(move || {
+        task::spawn_blocking(move || {
             loop {
                 if self.node.is_shutting_down() {
                     debug!("The node is shutting down, stopping mining");
@@ -66,7 +70,7 @@ impl<S: Storage + Send + Sync + 'static> MinerInstance<S> {
 
                 info!("Starting to mine the next block");
 
-                let (block, _coinbase_records) = match miner.mine_block() {
+                let (block, _coinbase_records) = match block_on(miner.mine_block()) {
                     Ok(mined_block) => mined_block,
                     Err(error) => {
                         // It's possible that the node realized that it needs to sync with another one in the
@@ -98,7 +102,7 @@ impl<S: Storage + Send + Sync + 'static> MinerInstance<S> {
                     self.node.set_state(State::Idle);
                 }
 
-                metrics::increment_counter!(stats::MISC_BLOCKS_MINED);
+                metrics::increment_counter!(BLOCKS_MINED);
 
                 info!("Mined a new block: {:?}", hex::encode(block.header.get_hash().0));
 
@@ -109,10 +113,8 @@ impl<S: Storage + Send + Sync + 'static> MinerInstance<S> {
                     continue;
                 };
 
-                self.node.propagate_block(serialized_block, local_address);
+                block_on(self.node.propagate_block(serialized_block, local_address));
             }
-        });
-
-        mining_thread.expect("failed to spawn the miner thread")
+        })
     }
 }
